@@ -26,6 +26,11 @@ import (
 	"time"
 )
 
+// Ptr is a helper returns a pointer to v.
+func Ptr[T any](v T) *T {
+	return &v
+}
+
 // AccessControlValue represents an access control value within GitLab,
 // used for managing access to certain project features.
 //
@@ -44,10 +49,10 @@ const (
 
 // AccessControl is a helper routine that allocates a new AccessControlValue
 // to store v and returns a pointer to it.
+//
+// Deprecated: Please use Ptr instead.
 func AccessControl(v AccessControlValue) *AccessControlValue {
-	p := new(AccessControlValue)
-	*p = v
-	return p
+	return Ptr(v)
 }
 
 // AccessLevelValue represents a permission level within GitLab.
@@ -76,10 +81,10 @@ const (
 
 // AccessLevel is a helper routine that allocates a new AccessLevelValue
 // to store v and returns a pointer to it.
+//
+// Deprecated: Please use Ptr instead.
 func AccessLevel(v AccessLevelValue) *AccessLevelValue {
-	p := new(AccessLevelValue)
-	*p = v
-	return p
+	return Ptr(v)
 }
 
 // UserIDValue represents a user ID value within GitLab.
@@ -217,10 +222,10 @@ const (
 
 // Availability is a helper routine that allocates a new AvailabilityValue
 // to store v and returns a pointer to it.
+//
+// Deprecated: Please use Ptr instead.
 func Availability(v AvailabilityValue) *AvailabilityValue {
-	p := new(AvailabilityValue)
-	*p = v
-	return p
+	return Ptr(v)
 }
 
 // BuildStateValue represents a GitLab build state.
@@ -243,10 +248,10 @@ const (
 
 // BuildState is a helper routine that allocates a new BuildStateValue
 // to store v and returns a pointer to it.
+//
+// Deprecated: Please use Ptr instead.
 func BuildState(v BuildStateValue) *BuildStateValue {
-	p := new(BuildStateValue)
-	*p = v
-	return p
+	return Ptr(v)
 }
 
 // DeploymentStatusValue represents a Gitlab deployment status.
@@ -263,10 +268,10 @@ const (
 
 // DeploymentStatus is a helper routine that allocates a new
 // DeploymentStatusValue to store v and returns a pointer to it.
+//
+// Deprecated: Please use Ptr instead.
 func DeploymentStatus(v DeploymentStatusValue) *DeploymentStatusValue {
-	p := new(DeploymentStatusValue)
-	*p = v
-	return p
+	return Ptr(v)
 }
 
 // EventTypeValue represents actions type for contribution events
@@ -321,10 +326,10 @@ const (
 
 // FileAction is a helper routine that allocates a new FileActionValue value
 // to store v and returns a pointer to it.
+//
+// Deprecated: Please use Ptr instead.
 func FileAction(v FileActionValue) *FileActionValue {
-	p := new(FileActionValue)
-	*p = v
-	return p
+	return Ptr(v)
 }
 
 // GenericPackageSelectValue represents a generic package select value.
@@ -337,10 +342,10 @@ const (
 
 // GenericPackageSelect is a helper routine that allocates a new
 // GenericPackageSelectValue value to store v and returns a pointer to it.
+//
+// Deprecated: Please use Ptr instead.
 func GenericPackageSelect(v GenericPackageSelectValue) *GenericPackageSelectValue {
-	p := new(GenericPackageSelectValue)
-	*p = v
-	return p
+	return Ptr(v)
 }
 
 // GenericPackageStatusValue represents a generic package status.
@@ -354,10 +359,10 @@ const (
 
 // GenericPackageStatus is a helper routine that allocates a new
 // GenericPackageStatusValue value to store v and returns a pointer to it.
+//
+// Deprecated: Please use Ptr instead.
 func GenericPackageStatus(v GenericPackageStatusValue) *GenericPackageStatusValue {
-	p := new(GenericPackageStatusValue)
-	*p = v
-	return p
+	return Ptr(v)
 }
 
 // ISOTime represents an ISO 8601 formatted date.
@@ -434,10 +439,10 @@ const (
 
 // LinkType is a helper routine that allocates a new LinkType value
 // to store v and returns a pointer to it.
+//
+// Deprecated: Please use Ptr instead.
 func LinkType(v LinkTypeValue) *LinkTypeValue {
-	p := new(LinkTypeValue)
-	*p = v
-	return p
+	return Ptr(v)
 }
 
 // LicenseApprovalStatusValue describe the approval statuses of a license.
@@ -455,10 +460,10 @@ const (
 
 // LicenseApprovalStatus is a helper routine that allocates a new license
 // approval status value to store v and returns a pointer to it.
+//
+// Deprecated: Please use Ptr instead.
 func LicenseApprovalStatus(v LicenseApprovalStatusValue) *LicenseApprovalStatusValue {
-	p := new(LicenseApprovalStatusValue)
-	*p = v
-	return p
+	return Ptr(v)
 }
 
 // MergeMethodValue represents a project merge type within GitLab.
@@ -476,11 +481,11 @@ const (
 )
 
 // MergeMethod is a helper routine that allocates a new MergeMethod
-// to sotre v and returns a pointer to it.
+// to store v and returns a pointer to it.
+//
+// Deprecated: Please use Ptr instead.
 func MergeMethod(v MergeMethodValue) *MergeMethodValue {
-	p := new(MergeMethodValue)
-	*p = v
-	return p
+	return Ptr(v)
 }
 
 // NoteTypeValue represents the type of a Note.
@@ -496,10 +501,10 @@ const (
 
 // NoteType is a helper routine that allocates a new NoteTypeValue to
 // store v and returns a pointer to it.
+//
+// Deprecated: Please use Ptr instead.
 func NoteType(v NoteTypeValue) *NoteTypeValue {
-	p := new(NoteTypeValue)
-	*p = v
-	return p
+	return Ptr(v)
 }
 
 // NotificationLevelValue represents a notification level.
@@ -566,10 +571,10 @@ var notificationLevelTypes = map[string]NotificationLevelValue{
 
 // NotificationLevel is a helper routine that allocates a new NotificationLevelValue
 // to store v and returns a pointer to it.
+//
+// Deprecated: Please use Ptr instead.
 func NotificationLevel(v NotificationLevelValue) *NotificationLevelValue {
-	p := new(NotificationLevelValue)
-	*p = v
-	return p
+	return Ptr(v)
 }
 
 // ProjectCreationLevelValue represents a project creation level within GitLab.
@@ -588,10 +593,9 @@ const (
 
 // ProjectCreationLevel is a helper routine that allocates a new ProjectCreationLevelValue
 // to store v and returns a pointer to it.
+// Please use Ptr instead.
 func ProjectCreationLevel(v ProjectCreationLevelValue) *ProjectCreationLevelValue {
-	p := new(ProjectCreationLevelValue)
-	*p = v
-	return p
+	return Ptr(v)
 }
 
 // SharedRunnersSettingValue determines whether shared runners are enabled for a
@@ -607,16 +611,19 @@ type SharedRunnersSettingValue string
 // https://docs.gitlab.com/ee/api/groups.html#options-for-shared_runners_setting
 const (
 	EnabledSharedRunnersSettingValue                  SharedRunnersSettingValue = "enabled"
-	DisabledWithOverrideSharedRunnersSettingValue     SharedRunnersSettingValue = "disabled_with_override"
+	DisabledAndOverridableSharedRunnersSettingValue   SharedRunnersSettingValue = "disabled_and_overridable"
 	DisabledAndUnoverridableSharedRunnersSettingValue SharedRunnersSettingValue = "disabled_and_unoverridable"
+
+	// Deprecated: DisabledWithOverrideSharedRunnersSettingValue is deprecated in favor of DisabledAndOverridableSharedRunnersSettingValue
+	DisabledWithOverrideSharedRunnersSettingValue SharedRunnersSettingValue = "disabled_with_override"
 )
 
 // SharedRunnersSetting is a helper routine that allocates a new SharedRunnersSettingValue
 // to store v and returns a pointer to it.
+//
+// Deprecated: Please use Ptr instead.
 func SharedRunnersSetting(v SharedRunnersSettingValue) *SharedRunnersSettingValue {
-	p := new(SharedRunnersSettingValue)
-	*p = v
-	return p
+	return Ptr(v)
 }
 
 // SubGroupCreationLevelValue represents a sub group creation level within GitLab.
@@ -634,10 +641,10 @@ const (
 
 // SubGroupCreationLevel is a helper routine that allocates a new SubGroupCreationLevelValue
 // to store v and returns a pointer to it.
+//
+// Deprecated: Please use Ptr instead.
 func SubGroupCreationLevel(v SubGroupCreationLevelValue) *SubGroupCreationLevelValue {
-	p := new(SubGroupCreationLevelValue)
-	*p = v
-	return p
+	return Ptr(v)
 }
 
 // SquashOptionValue represents a squash optional level within GitLab.
@@ -657,10 +664,10 @@ const (
 
 // SquashOption is a helper routine that allocates a new SquashOptionValue
 // to store s and returns a pointer to it.
+//
+// Deprecated: Please use Ptr instead.
 func SquashOption(s SquashOptionValue) *SquashOptionValue {
-	p := new(SquashOptionValue)
-	*p = s
-	return p
+	return Ptr(s)
 }
 
 // TasksCompletionStatus represents tasks of the issue/merge request.
@@ -720,10 +727,10 @@ const (
 
 // VariableType is a helper routine that allocates a new VariableTypeValue
 // to store v and returns a pointer to it.
+//
+// Deprecated: Please use Ptr instead.
 func VariableType(v VariableTypeValue) *VariableTypeValue {
-	p := new(VariableTypeValue)
-	*p = v
-	return p
+	return Ptr(v)
 }
 
 // VisibilityValue represents a visibility level within GitLab.
@@ -742,10 +749,10 @@ const (
 
 // Visibility is a helper routine that allocates a new VisibilityValue
 // to store v and returns a pointer to it.
+//
+// Deprecated: Please use Ptr instead.
 func Visibility(v VisibilityValue) *VisibilityValue {
-	p := new(VisibilityValue)
-	*p = v
-	return p
+	return Ptr(v)
 }
 
 // WikiFormatValue represents the available wiki formats.
@@ -763,42 +770,42 @@ const (
 
 // WikiFormat is a helper routine that allocates a new WikiFormatValue
 // to store v and returns a pointer to it.
+//
+// Deprecated: Please use Ptr instead.
 func WikiFormat(v WikiFormatValue) *WikiFormatValue {
-	p := new(WikiFormatValue)
-	*p = v
-	return p
+	return Ptr(v)
 }
 
 // Bool is a helper routine that allocates a new bool value
 // to store v and returns a pointer to it.
+//
+// Deprecated: Please use Ptr instead.
 func Bool(v bool) *bool {
-	p := new(bool)
-	*p = v
-	return p
+	return Ptr(v)
 }
 
 // Int is a helper routine that allocates a new int value
 // to store v and returns a pointer to it.
+//
+// Deprecated: Please use Ptr instead.
 func Int(v int) *int {
-	p := new(int)
-	*p = v
-	return p
+	return Ptr(v)
 }
 
 // String is a helper routine that allocates a new string value
 // to store v and returns a pointer to it.
+//
+// Deprecated: Please use Ptr instead.
 func String(v string) *string {
-	p := new(string)
-	*p = v
-	return p
+	return Ptr(v)
 }
 
 // Time is a helper routine that allocates a new time.Time value
 // to store v and returns a pointer to it.
+//
+// Deprecated: Please use Ptr instead.
 func Time(v time.Time) *time.Time {
-	p := new(time.Time)
-	*p = v
-	return p
+	return Ptr(v)
 }
 
 // BoolValue is a boolean value with advanced json unmarshaling features.
