@@ -24,8 +24,7 @@ import (
 )
 
 func TestGetVersion(t *testing.T) {
-	mux, server, client := setup(t)
-	defer teardown(server)
+	mux, client := setup(t)
 
 	mux.HandleFunc("/api/v4/version",
 		func(w http.ResponseWriter, r *http.Request) {
